@@ -4,7 +4,7 @@
 ;; Copyright (C) 1997 Klee Dienes
 ;; Copyright (C) 1999 Chris Waters
 ;; Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005 Peter S Galbraith
-;; Copyright (C) 2006, 2007, 2008, Peter S Galbraith
+;; Copyright (C) 2006, 2007, 2009, 2010 Peter S Galbraith
 ;;
 ;; This file is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -18,8 +18,8 @@
 ;;
 ;; You should have received a copy of the GNU General Public License
 ;; along with your Debian installation, in /usr/share/common-licenses/GPL
-;; If not, write to the Free Software Foundation, 675 Mass Ave,
-;; Cambridge, MA 02139, USA.
+;; If not, write to the Free Software Foundation, 51 Franklin Street,
+;; Suite 500 Boston, MA 02110-1335, USA 
 
 ;;; Commentary:
 ;;
@@ -332,6 +332,20 @@
 ;;    See http://bugs.debian.org/457047
 ;; V1.89 23Feb2009 Jari.aalto@cante.net
 ;;  - finalize date in UTC (User configurable) (Closes: #503700)
+;; V1.90 24Oct2009 Rafael Laboissiere <rafael@debian.org>
+;;  - debian-changelog-close-bug does not work properly under XEmacs 21.4.21
+;;    because the arguments passed to replace-in-string in the inline function
+;;    debian-chagelog--rris are in the wrong order. Closes: #476271
+;; V1.91 12Nov2009 Peter S Galbraith <psg@debian.org>
+;;    Updated URL for "Best practices".
+;; V1.92 27Apr2010 Peter S Galbraith <psg@debian.org>
+;;    Invoke `debian-bug-build-bug-menu' with SOURCE arg set to t.
+;;    Needs debian-el 33.2
+;; V1.93 10May2010 Peter S Galbraith <psg@debian.org>
+;;    Fix typo (Closes: #580818)
+;; V1.94 28Jul2010 Kevin Ryde <user42@zip.com.au>
+;;    Simplify auto-mode-alist (Closes: #587924)
+;;
 ;;; Acknowledgements:  (These people have contributed)
 ;;   Roland Rosenfeld <roland@debian.org>
 ;;   James LewisMoss <dres@ioa.com>
@@ -415,7 +429,7 @@ new version in debian/changelog."
 (defcustom debian-changelog-date-utc-flag nil
   "If non-nil, return date string in UTC when finalizing entry.
 See function `debian-changelog-date-string'."
-  :group 'debian-changelogx
+  :group 'debian-changelog
   :type 'boolean)
 
 ;; This function is from emacs/lisp/calendar/icalendar.el,
@@ -428,7 +442,10 @@ Pass ARGS to `replace-regexp-in-string' (GNU Emacs) or to
   ;; XEmacs:
   (if (fboundp 'replace-in-string)
       (save-match-data ;; apparently XEmacs needs save-match-data
-        (apply 'replace-in-string args))
+        ;; and arguments are in different order.
+        ;; Patch from Rafael Laboissiere <rafael@debian.org>
+        ;; Closes: #476271
+        (apply 'replace-in-string (list (nth 2 args) (nth 0 args) (nth 1 args))))
     ;; Emacs:
     (apply 'replace-regexp-in-string args)))
 
@@ -687,7 +704,7 @@ Upload to " val  " anyway?")))
     (not (debian-changelog-finalised-p))]
    "--"
    "Web View"
-   ["Best Practices" (browse-url "http://www.debian.org/doc/developers-reference/ch-best-pkging-practices.en.html#s-bpp-debian-changelog") t]
+   ["Best Practices" (browse-url "http://www.debian.org/doc/developers-reference/best-pkging-practices.html#bpp-debian-changelog") t]
    ["Bugs for This Package" (debian-bug-web-bugs) t]
    ["Archived Bugs for This Package" (debian-bug-web-bugs t) t]
    ["Bug Number..." (debian-bug-web-bug) t]
@@ -828,7 +845,7 @@ for the debian/changelog file to add the entry to."
 (defun debian-changelog-build-open-bug-list ()
   "Generate open bugs list, i.e. `debian-bug-open-alist'."
   (interactive)
-  (debian-bug-build-bug-menu (debian-changelog-suggest-package-name)))
+  (debian-bug-build-bug-menu (debian-changelog-suggest-package-name) t))
 
 (defun debian-changelog-close-bug (bug-number)
   "Add a new change entry to close a BUG-NUMBER."
@@ -1759,10 +1776,12 @@ Also set keymap."
 
 ;;; Setup auto-mode-alist
 ;; (in case /etc/emacs/site-start.d/50dpkg-dev.el not used)
+;;
+;; Crib note: no need for "NEWS.Debian.gz" or "changelog.Debian.gz" entries
+;; since jka-compr.el dispatches using the basename after uncompressing.
 
 (add-to-list 'auto-mode-alist '("/debian/*NEWS" . debian-changelog-mode))
 (add-to-list 'auto-mode-alist '("NEWS.Debian" . debian-changelog-mode))
-(add-to-list 'auto-mode-alist '("NEWS.Debian.gz" . debian-changelog-mode))
 
 ;;(add-to-list 'auto-mode-alist '("/debian/changelog\\'" . debian-changelog-mode))
 ;;; Instead use this.  See http://bugs.debian.org/457047 by Trent W. Buck
@@ -1773,16 +1792,13 @@ Also set keymap."
    . debian-changelog-mode))
 
 (add-to-list 'auto-mode-alist '("changelog.Debian" . debian-changelog-mode))
-(add-to-list 'auto-mode-alist '("changelog.Debian.gz" . debian-changelog-mode))
   ;; For debchange
 (add-to-list 'auto-mode-alist '("changelog.dch" . debian-changelog-mode))
 
 ;;;###autoload(add-to-list 'auto-mode-alist '("/debian/*NEWS" . debian-changelog-mode))
 ;;;###autoload(add-to-list 'auto-mode-alist '("NEWS.Debian" . debian-changelog-mode))
-;;;###autoload(add-to-list 'auto-mode-alist '("NEWS.Debian.gz" . debian-changelog-mode))
 ;;;###autoload(add-to-list 'auto-mode-alist '("/debian/\\([[:lower:][:digit:]][[:lower:][:digit:].+-]+\\.\\)?changelog\\'" . debian-changelog-mode))
 ;;;###autoload(add-to-list 'auto-mode-alist '("changelog.Debian" . debian-changelog-mode))
-;;;###autoload(add-to-list 'auto-mode-alist '("changelog.Debian.gz" . debian-changelog-mode))
 ;;;###autoload(add-to-list 'auto-mode-alist '("changelog.dch" . debian-changelog-mode))
 
 (provide 'debian-changelog-mode)
